from urllib.parse import urlencode
import urllib.request
from urllib.request import Request
import os
from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from abc import ABC, abstractmethod


class Downloader(ABC):
    def __init__(self):
        pass

    @abstractmethod
    def download(self, url, post=None):
        pass

    def get_content(self, url, cache=None, referer=None, post=None):
        if cache and os.path.exists(cache):
            print("Loading cache ({})".format(cache))
            with open(cache) as f:
                content = "\n".join(f.readlines())
        else:
            content = self.download(url, referer=referer, post=post)

            if cache:
                print("Saving cache ({})".format(cache))
                dir = os.path.dirname(cache)
                if dir != "" and not os.path.exists(dir):
                    os.makedirs(dir)
                with open(cache, "w") as text_file:
                    text_file.write(content)
        return content


class SimpleDownloader(Downloader):
    def __init__(self):
        super().__init__()

    def download(self, url, referer=None, post=None):
        print("Downloading {} referer: {} post: {}".format(url, referer, post))
        try:
            headers = {
                "User-Agent": "Mozilla/5.0 (X11; Linux x86_64; rv:126.0) Gecko/20100101 Firefox/126.0",
            }
            if referer is not None:
                headers["Referer"] = referer
            req = Request(url, headers=headers)
            if post:
                post_args = urlencode(post).encode("utf-8")
                resource = urllib.request.urlopen(req, post_args)
            else:
                resource = urllib.request.urlopen(req)
            data = resource.read().decode(resource.headers.get_content_charset())
            return data
        except Exception as e:
            print(e)
            return None


class ChromiumHeadlessDownloader(Downloader):
    def __init__(self):
        super().__init__()
        self.options = Options()
        self.options.add_argument("--headless=new")
        self.options.add_argument("--disable-dev-shm-usage")
        self.options.add_argument("--no-sandbox")
        self.options.add_experimental_option(
            "prefs", {
                # block image loading
                "profile.managed_default_content_settings.images": 2,
            }
        )

        self.service = Service("/usr/bin/chromedriver")
        self.driver = webdriver.Chrome(service=self.service, options=self.options)

    def download(self, url, referer=None, post=None):
        if post:
            raise Exception("POST method with Chromium headless not yet implemented")
        print("Download {}".format(url))

        self.driver.get(url)
        doc = self.driver.page_source
        return doc
