from django import template
from django.utils.safestring import mark_safe
from django.urls import reverse_lazy
from django.template.defaultfilters import pluralize
from django.db.models import OuterRef, Subquery


from agenda_culturel.models import RecurrentImport, BatchImportation

from .utils_extra import picto_from_name

register = template.Library()


@register.simple_tag
def show_badge_failed_rimports(placement="top"):
    newest = BatchImportation.objects.filter(recurrentImport=OuterRef("pk")).order_by(
        "-created_date"
    )
    nb_failed = (
        RecurrentImport.objects.annotate(
            last_run_status=Subquery(newest.values("status")[:1])
        )
        .filter(last_run_status=BatchImportation.STATUS.FAILED)
        .count()
    )

    if nb_failed != 0:
        return mark_safe(
            '<a href="'
            + reverse_lazy("recurrent_imports")
            + '" class="badge error" data-placement="'
            + placement
            + '" data-tooltip="'
            + str(nb_failed)
            + " importation"
            + pluralize(nb_failed)
            + " récurrente"
            + pluralize(nb_failed)
            + ' en erreur">'
            + picto_from_name("alert-triangle")
            + " "
            + str(nb_failed)
            + "</a>"
        )
    else:
        return ""
